Welcome to HoloViews!
_____________________

This 'Getting Started' guide aims to get you using HoloViews
productively as quickly as possible. It is designed as an entrypoint for
new users that will introduce the core concepts necessary to get you
working productively with your own data. We recommend reading this guide
in order if you wish to get an overview of what is offered by HoloViews.

For detailed documentation, please consult our `User Guide
<../user_guide/index.html>`_ which we will link to from the appropriate
sections of this guide. An overview of some interesting HoloViews
examples can be found in our `Gallery <../gallery/index.html>`_ and if
you are looking for a specific component (or wish to view the available
range of primitives), see our `Reference Gallery
<../reference/index.html>`_.

* `Introduction <Introduction.html>`_
   What is HoloViews?

* `Customization <Customization.html>`_
   How to customize the visual representation.

* `Tabular Datasets <Tabular_Datasets.html>`_
   Introduction to working with tabular data.

* `Gridded Datasets <Gridded_Datasets.html>`_
   Introduction to working with array data.

* `Live Data <Live_Data.html>`_
   Working with dynamically generated data.

.. toctree::
    :titlesonly:
    :hidden:
    :maxdepth: 2

    Introduction <Introduction>
    Customization <Customization>
    Tabular Datasets <Tabular_Datasets>
    Gridded Datasets <Gridded_Datasets>
    Live Data <Live_Data>
